# dialog-workflow-local-python-package

TODO for the future to write programs that validate the scripts and check there are always options for
multi_choice_poll()<br>

TODO def get_dialog_workflow_profile_id( profile_id1, prompt: str, profile_id2 = None, group_id) -> int:

# If profile_id2 is None or profile.id2 is Business Profile - Use avatar_table and avatar_group_table to determine who

will answer.

# Look at previous conversations

# Look for relevant avatar profile_id for the profile_id1

Each thread of Dialog Workflow Local is working with one effective_profile_id
Dialog Workflow sends CompoundMessage to one recipient / effective_profile_id
The Dialog Workflow can send Compound Messages which include forms

TODO Add support to question

TODO Add support to multi-question sent to the client
